pyxmpp2.sasl.external.ExternalClientAuthenticator

Package pyxmpp2 :: Package sasl :: Module external :: Class ExternalClientAuthenticator |
[hide private]

# Class ExternalClientAuthenticator

Provides client-side External SASL (TLS-Identify) authentication.

Nested Classes | [hide private]
Inherited from `core.ClientAuthenticator`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a ClientAuthenticator object. |
Response or Failure |
start(self, username, authzid) Start the authentication process. |
Success |
finish(self, data) Handle authentication success information from the server. |
Inherited from `core.ClientAuthenticator`: `challenge` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _abc_cache = `<_weakrefset.WeakSet object at 0x87908ec>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x879092c>`
| _pyxmpp_sasl_preference = `20`
| _pyxmpp_sasl_secure = `False`
Inherited from `core.ClientAuthenticator`: `__abstractmethods__` Inherited from `core.ClientAuthenticator` (private): `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) |
Initialize a ClientAuthenticator object. Parameters: `password_manager` - a password manager providing authentication credentials. Overrides: object.__init__ (inherited documentation)

### start(self, username, authzid) |
Start the authentication process. Parameters: `username` - the username (authentication id). `authzid` - the authorization id requester. Returns: Response or Failure the initial response to send to the server or a failuer indicator. Overrides: core.ClientAuthenticator.start (inherited documentation)

### finish(self, data) |
Handle authentication success information from the server. Parameters: `data` (`str`) - the optional additional data returned with the success. Returns: Success a success indicator. Overrides: core.ClientAuthenticator.finish